]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - write.h
write: Simplify config parsers.
[paraslash.git] / write.h
diff --git a/write.h b/write.h
index 1361fcf1d052b31596f1407a81cc485b5fa833e1..fd0f4f6ba7b42b186eab05efbc5ee61cdf499140 100644 (file)
--- a/write.h
+++ b/write.h
@@ -36,16 +36,18 @@ struct writer {
        /**
         * The command line parser of the writer.
         *
* It should check whether the command line options given by \a options are
* valid.  On success, it should return a pointer to the writer-specific
* configuration data determined by \a options.  Note that this might be called
* more than once with different values of \a options. \sa \ref free_config().
         */
-       void *(*parse_config)(const char *options);
+       void *(*parse_config_or_die)(const char *options);
        /**
         * Dellocate all configuration resources.
         *
* This should free whatever was allocated by \ref parse_config().
         */
        void (*free_config)(void *config);
        /**
@@ -36,16 +36,18 @@ struct writer {
         * The command line parser of the writer.
         *
-        * It should check whether the command line options given by \a options are
-        * valid.  On success, it should return a pointer to the writer-specific
-        * configuration data determined by \a options.  Note that this might be called
-        * more than once with different values of \a options. \sa \ref free_config().
+        * It should check whether the command line options given by \a options
+        * are valid and return a pointer to the writer-specific configuration
+        * data determined by \a options. This function must either succeed or
+        * call exit(). Note that parse_config_or_die() might be called more
+        * than once with different values of \a options. \sa \ref
+        * free_config().
         */
@@ -36,16 +36,18 @@ struct writer {
         * Dellocate all configuration resources.
         *
-        * This should free whatever was allocated by \ref parse_config().
+        * This should free whatever was allocated by \ref parse_config_or_die().
         */
        void (*free_config)(void *config);